"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const common_1 = require("../common");
const jsf = require("json-schema-faker");
const types_1 = require("../types");
function createPubSubdata(input, stringify = true) {
    const message = jsf.generate(types_1.PubSubMessage);
    const data = Buffer.from(stringify ? JSON.stringify(input) : input).toString('base64');
    return Object.assign(Object.assign({}, message), { data });
}
describe('common', () => {
    it('should handle simple PubSub messages', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const message = createPubSubdata('hello-world', false);
        const handler = jest.fn();
        yield common_1.handlePubSubMessage({ message, handler, parseJson: false });
        expect(handler).toHaveBeenCalledWith({ message, data: 'hello-world' });
    }));
    it('should handle JSON PubSub messages', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const message = createPubSubdata({ name: 'Simen' });
        const handler = jest.fn();
        yield common_1.handlePubSubMessage({
            message,
            handler,
            parseJson: true,
        });
        expect(handler).toHaveBeenCalledWith({ message, data: { name: 'Simen' } });
    }));
    it('should pass context', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const message = createPubSubdata('');
        const handler = jest.fn();
        yield common_1.handlePubSubMessage({
            message,
            handler,
            context: { hello: 'there' },
        });
        expect(handler).toHaveBeenCalledWith({
            message,
            data: '',
            context: { hello: 'there' },
        });
    }));
});
